class KW:
    id = "_id"
    filter = "filter"
    fields = "fields"
    region = "ga_region"
    projection = "projection"
    document = "document"
    forced_projection = "forced_projection"
